@@ -1,9 +1,9 @@
 package App::lcpan::Cmd::dists_by_dep_count;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-07'; # DATE
+our $DATE = '2020-05-26'; # DATE
 our $DIST = 'App-lcpan'; # DIST
-our $VERSION = '1.057'; # VERSION
+our $VERSION = '1.058'; # VERSION
 
 use 5.010;
 use strict;
@@ -23,6 +23,10 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::fauthor_args,
         clone_list(%App::lcpan::deps_phase_args),
         clone_list(%App::lcpan::deps_rel_args),
+        n => {
+            summary => 'Return at most this number of results',
+            schema => 'posint*',
+        },
     },
 };
 delete $SPEC{'handle_cmd'}{args}{phase}{default};
@@ -36,30 +40,30 @@ sub handle_cmd {
     my @where;
     my @binds;
     if ($args{author}) {
-        push @where, "(author=?)";
+        push @where, "(file.author=?)";
         push @binds, $args{author};
     }
     if ($args{phase} && $args{phase} ne 'ALL') {
-        push @where, "(phase=?)";
+        push @where, "(dep.phase=?)";
         push @binds, $args{phase};
     }
     if ($args{rel} && $args{rel} ne 'ALL') {
-        push @where, "(rel=?)";
+        push @where, "(dep.rel=?)";
         push @binds, $args{rel};
     }
-    push @where, "f.is_latest_dist";
+    push @where, "file.is_latest_dist";
     @where = (1) if !@where;
 
     my $sql = "SELECT
-  f.dist_name name,
-  f.cpanid author,
-  COUNT(DISTINCT f.id) AS dep_count
-FROM file f
-JOIN dep dp ON dp.file_id=f.id
+  file.dist_name dist,
+  file.cpanid author,
+  COUNT(DISTINCT dep.module_id) AS dep_count
+FROM dep
+LEFT JOIN file ON dep.file_id=file.id
 WHERE ".join(" AND ", @where)."
-GROUP BY id
+GROUP BY dep.file_id
 ORDER BY dep_count DESC
-";
+".($args{n} ? "LIMIT ".(0+$args{n}) : "");
 
     my @res;
     my $sth = $dbh->prepare($sql);
@@ -87,7 +91,7 @@ App::lcpan::Cmd::dists_by_dep_count - List "heavy" distributions (ranked by numb
 
 =head1 VERSION
 
-This document describes version 1.057 of App::lcpan::Cmd::dists_by_dep_count (from Perl distribution App-lcpan), released on 2020-05-07.
+This document describes version 1.058 of App::lcpan::Cmd::dists_by_dep_count (from Perl distribution App-lcpan), released on 2020-05-26.
 
 =head1 FUNCTIONS
 
@@ -125,6 +129,10 @@ be located in the top-level of C<cpan>. If C<index_name> contains a path, e.g.
 C<./index.db> or C</home/ujang/lcpan.db> then the index will be located solely
 using the C<index_name>.
 
+=item * B<n> => I<posint>
+
+Return at most this number of results.
+
 =item * B<phase> => I<str>
 
 =item * B<rel> => I<str>
