@@ -1,5 +1,10 @@
 package App::lcpan::Cmd::most_depended_mods;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-26'; # DATE
+our $DIST = 'App-lcpan'; # DIST
+our $VERSION = '1.058'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -8,11 +13,6 @@ use Function::Fallback::CoreOrPP qw(clone);
 
 require App::lcpan::Cmd::mods_by_rdep_count;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-07'; # DATE
-our $DIST = 'App-lcpan'; # DIST
-our $VERSION = '1.070_001'; # TRIAL VERSION
-
 our %SPEC;
 
 $SPEC{handle_cmd} = do {
@@ -38,7 +38,7 @@ App::lcpan::Cmd::most_depended_mods - Alias for 'mods-by-rdep-count', with defau
 
 =head1 VERSION
 
-This document describes version 1.070_001 of App::lcpan::Cmd::most_depended_mods (from Perl distribution App-lcpan), released on 2022-05-07.
+This document describes version 1.058 of App::lcpan::Cmd::most_depended_mods (from Perl distribution App-lcpan), released on 2020-05-26.
 
 =head1 FUNCTIONS
 
@@ -47,7 +47,7 @@ This document describes version 1.070_001 of App::lcpan::Cmd::most_depended_mods
 
 Usage:
 
- handle_cmd(%args) -> [$status_code, $reason, $payload, \%result_meta]
+ handle_cmd(%args) -> [status, msg, payload, meta]
 
 Alias for 'mods-by-rdep-count', with default n=100.
 
@@ -96,12 +96,12 @@ off.
 
 Returns an enveloped result (an array).
 
-First element ($status_code) is an integer containing HTTP-like status code
+First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-($reason) is a string containing error message, or something like "OK" if status is
-200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
-element (%result_meta) is called result metadata and is optional, a hash
-that contains extra information, much like how HTTP response headers provide additional metadata.
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 Return value:  (any)
 
@@ -113,34 +113,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>
 
 Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 CONTRIBUTING
-
-
-To contribute, you can send patches by email/via RT, or send pull requests on
-GitHub.
-
-Most of the time, you don't need to build the distribution yourself. You can
-simply modify the code, then test via:
-
- % prove -l
-
-If you want to build the distribution (e.g. to try to install it locally on your
-system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>
@@ -149,4 +121,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
