@@ -1,7 +1,9 @@
 package App::lcpan::Cmd::scripts_by_mention_count;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '1.057'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-26'; # DATE
+our $DIST = 'App-lcpan'; # DIST
+our $VERSION = '1.058'; # VERSION
 
 use 5.010;
 use strict;
@@ -40,6 +42,10 @@ _
             schema => ['str*', in=>['content', 'dist', 'author']],
             default => 'content',
         },
+        n => {
+            summary => 'Return at most this number of results',
+            schema => 'posint*',
+        },
     },
 };
 sub handle_cmd {
@@ -64,6 +70,7 @@ sub handle_cmd {
 
     my $sql = "SELECT
   script.name script,
+  targetfile.cpanid author,
   COUNT($count) AS mention_count
 FROM mention
 LEFT JOIN file srcfile ON mention.source_file_id=srcfile.id
@@ -72,7 +79,7 @@ LEFT JOIN file targetfile ON script.file_id=targetfile.id
 WHERE ".join(" AND ", @where)."
 GROUP BY script.name
 ORDER BY mention_count DESC
-";
+".($args{n} ? "LIMIT ".(0+$args{n}) : "");
 
     my @res;
     my $sth = $dbh->prepare($sql);
@@ -100,7 +107,7 @@ App::lcpan::Cmd::scripts_by_mention_count - List scripts ranked by number of men
 
 =head1 VERSION
 
-This document describes version 1.057 of App::lcpan::Cmd::scripts_by_mention_count (from Perl distribution App-lcpan), released on 2020-05-07.
+This document describes version 1.058 of App::lcpan::Cmd::scripts_by_mention_count (from Perl distribution App-lcpan), released on 2020-05-26.
 
 =head1 FUNCTIONS
 
@@ -151,6 +158,10 @@ be located in the top-level of C<cpan>. If C<index_name> contains a path, e.g.
 C<./index.db> or C</home/ujang/lcpan.db> then the index will be located solely
 using the C<index_name>.
 
+=item * B<n> => I<posint>
+
+Return at most this number of results.
+
 =item * B<use_bootstrap> => I<bool> (default: 1)
 
 Whether to use bootstrap database from App-lcpan-Bootstrap.
